@@ -620,22 +620,17 @@ def extract_TTTEEE_mbb(mbb_inv):
     mbb_inv: 2d array
       the inverse spin0 and 2 mode coupling matrix
     """
-
-    mbb_inv_array = so_mcm.coupling_dict_to_array(mbb_inv)
-    mbb_array = np.linalg.inv(mbb_inv_array)
-    nbins = int(mbb_array.shape[0] / 9)
-    
-    mbb_array_select = np.zeros((4*nbins, 4*nbins))
+    nbins = mbb_inv["spin0xspin0"].shape[0]
+    mbb_inv_array = np.zeros((4*nbins, 4*nbins))
     # TT
-    mbb_array_select[0*nbins:1*nbins, 0*nbins:1*nbins] = mbb_array[0*nbins:1*nbins, 0*nbins:1*nbins]
+    mbb_inv_array[0*nbins:1*nbins, 0*nbins:1*nbins] = mbb_inv["spin0xspin0"]
     # TE
-    mbb_array_select[1*nbins:2*nbins, 1*nbins:2*nbins] = mbb_array[1*nbins:2*nbins, 1*nbins:2*nbins]
+    mbb_inv_array[1*nbins:2*nbins, 1*nbins:2*nbins] = mbb_inv["spin0xspin2"]
     # ET
-    mbb_array_select[2*nbins:3*nbins, 2*nbins:3*nbins] = mbb_array[3*nbins:4*nbins, 3*nbins:4*nbins]
+    mbb_inv_array[2*nbins:3*nbins, 2*nbins:3*nbins] = mbb_inv["spin2xspin0"]
     # EE
-    mbb_array_select[3*nbins:4*nbins, 3*nbins:4*nbins] = mbb_array[5*nbins:6*nbins, 5*nbins:6*nbins]
+    mbb_inv_array[3*nbins:4*nbins, 3*nbins:4*nbins] = mbb_inv["spin2xspin2"][0:nbins, 0:nbins]
 
-    mbb_inv_array = np.linalg.inv(mbb_array_select)
     
     return mbb_inv_array
 
@@ -649,30 +644,22 @@ def extract_EEEBBB_mbb(mbb_inv):
         the inverse spin0 and 2 mode coupling matrix
     """
 
-    mbb_inv_array = so_mcm.coupling_dict_to_array(mbb_inv)
-    mbb_array = np.linalg.inv(mbb_inv_array)
-    nbins = int(mbb_array.shape[0] / 9)
+    return mbb_inv["spin2xspin2"]
 
-    mbb_array_select = np.zeros((4*nbins, 4*nbins))
-    # EE
-    mbb_array_select[0*nbins:1*nbins, 0*nbins:1*nbins] = mbb_array[5*nbins:6*nbins, 5*nbins:6*nbins]
-    # EB
-    mbb_array_select[1*nbins:2*nbins, 1*nbins:2*nbins] = mbb_array[6*nbins:7*nbins, 6*nbins:7*nbins]
-    # BE
-    mbb_array_select[2*nbins:3*nbins, 2*nbins:3*nbins] = mbb_array[7*nbins:8*nbins, 7*nbins:8*nbins]
-    # BB
-    mbb_array_select[3*nbins:4*nbins, 3*nbins:4*nbins] = mbb_array[8*nbins:9*nbins, 8*nbins:9*nbins]
-    # EE-BB
-    mbb_array_select[0*nbins:1*nbins, 3*nbins:4*nbins] = mbb_array[5*nbins:6*nbins, 8*nbins:9*nbins]
-    # BB-EE
-    mbb_array_select[3*nbins:4*nbins, 0*nbins:1*nbins] = mbb_array[8*nbins:9*nbins, 5*nbins:6*nbins]
+def corr2cov(corr, var):
+    """Go from correlation and variance to covariance matrix
 
-    mbb_inv_array = np.linalg.inv(mbb_array_select)
-
-    return mbb_inv_array
+    Parameters
+    ----------
+    corr: 2d array
+      the correlation matrix
+    var: 1d array
+      vector of variance of the random variables
+    """
+    return corr * np.sqrt(var[:, None] * var[None, :])
 
 
-def cov2corr(cov, remove_diag=True):
+def cov2corr(cov, remove_diag=False):
     """Go from covariance to correlation matrix, also setting the diagonal to zero
 
     Parameters
@@ -687,7 +674,7 @@ def cov2corr(cov, remove_diag=True):
         corr -= np.identity(cov.shape[0])
     return corr
 
-def selectblock(cov, spectra, n_bins, block="TTTT"):
+def selectblock(cov, spectra_order, n_bins, block="TTTT"):
     """Select a block in a spin0 and 2 covariance matrix
 
     Parameters
@@ -695,7 +682,7 @@ def selectblock(cov, spectra, n_bins, block="TTTT"):
 
     cov: 2d array
       the covariance matrix
-    spectra: list of strings
+    spectra_order: list of strings
       the arangement of the different block
     n_bins: int
       the number of bins for each block
@@ -703,19 +690,40 @@ def selectblock(cov, spectra, n_bins, block="TTTT"):
       the block you want to look at
     """
 
-    if spectra == None:
+    if spectra_order == None:
         print ("cov mat of spin 0, no block selection needed")
         return
     else:
         blockindex = {}
-        for c1,s1 in enumerate(spectra):
-            for c2,s2 in enumerate(spectra):
+        for c1,s1 in enumerate(spectra_order):
+            for c2,s2 in enumerate(spectra_order):
                 blockindex[s1 + s2] = [c1 * n_bins, c2 * n_bins]
     id1 = blockindex[block][0]
     id2 = blockindex[block][1]
     cov_select = cov[id1:id1 + n_bins, id2:id2 + n_bins]
     return cov_select
 
+def get_sigma(cov, spectra_order, n_bins, spectrum):
+    """get the error of the spectrum for the given cov mat
+
+    Parameters
+    ----------
+
+    cov: 2d array
+      the covariance matrix
+    spectra_order: list of strings
+      the arangement of the different block
+    n_bins: int
+      the number of bins for each block
+    spectrum: string
+      the spectrum we consider
+    """
+    cov_sub = selectblock(cov, spectra_order, n_bins, block=spectrum+spectrum)
+    err = np.sqrt(cov_sub.diagonal())
+    return err
+
+
+
 def delta2(a, b):
     """Simple delta function
     """
